clear all
clc

delta_D = [0.5 0.6 0.7 0.8 0.9 0.92 0.94 0.96 0.98];

alpha = 0.9;
r2 = 10e-3;
r1 = alpha*r2;

dt = 1e-7;
t_max = 0.005;

t = [0:dt:t_max];

rho = 1000;
ny = 0.001;
mu = ny*rho;
freq = 300; % [Hertz]
omega = 2*pi*freq;
A = 0.25;

a = A.*sin(omega.*t);
v = (A./omega).*(1-cos(omega.*t));
y = (A./omega).*(t-(sin(omega.*t)./omega));

% A(1) = (ri^2*ln(ri)-r2^2*ln(r2))/(2*(r2^2-ri^2))*; 
% B(1) = (ri^2*r2^2 )/2*(r2^2-ri^2)*ln();

K_alpha(1) = (r2/(4*(gamma(1)-1)))*(((2*gamma(1)*log(gamma(1))^2)/(gamma(1)^2-1))-(gamma(1)^2-1)/(2*gamma(1)));
K_beta(1) = (1/2*(gamma(1)-1))*((2*gamma(1)^2*log(gamma(1)))/(gamma(1)^2-1)-1);

N=length(t);

dtheta = 1; % 
theta = [1:dtheta:360].*((2*pi)/360);
N_theta = length(theta);

gamma = zeros(N,N_theta);
ri = zeros(N,N_theta);
dP_dtheta = zeros(N,N_theta);

ri(1,:) = r1;
gamma(1,:) = r2/r1;

    for i=2:N
    
        ri(i,:) = sqrt(r1.^2+(y(i)-y(i-1))^2+2.*r1.*(y(i)-y(i-1)).*sin(theta(:)));

        gamma(i,:) = r2./ri(i,:);
        
%         A(i) = ;
%         B(i) = ;

        K_alpha(i) = (r2/(4*(gamma(i)-1)))*(((2*gamma(i)*log(gamma(i))^2)/(gamma(i)^2-1))-(gamma(i)^2-1)/(2*gamma(i)));

        K_beta(i) = (1/2*(gamma(i)-1))*((2*gamma(i)^2*log(gamma(i)))/(gamma(i)^2-1)-1);

        dP_dtheta(i,:) = -(mu./K_alpha(i)).*((r1./ri(i,:))/(gamma(i,:)-1)+K_beta(i)).*v(i).*cos(theta(:));

    end
    
    
    d_angle = 10;
    angle_max = 90;
    N_angle = 1+angle_max/d_angle;
    angle = [0:d_angle:angle_max];
    
    for j=1:N_angle
        
        leg(j,:) = {sprintf('Theta angle of %2.0f',(j-1)*d_angle)};
        
        x = t_max*(0:(1/(length(dP_dtheta)-1)):1);       
        fig1=figure(1);
        hold all
%        xlim([0 360])

    if (j-1) == 0
    
        plot(x,dP_dtheta(:,360))
        grad_max(1) = max(dP_dtheta(:,360));

    else

        plot(x,dP_dtheta(:,(j-1)*d_angle))
        grad_max(j) = max(dP_dtheta(:,(j-1)*d_angle));

    end
       
    end
    
xlabel('Time [sec]')
ylabel('Pressure gradient [N/mm]')
legend(leg,'Location','NorthEastOutside')
title_handle = {'Analytical solution for pressure gradient, Alpha = 0.9, 1e-3 m^2/s in viscosity,';...
    '0.25 in amplitude and frequency of 300 Hz.'};
title(title_handle,'FontWeight','bold')
set(gca, 'ActivePositionProperty', 'OuterPosition');
fig_name = 'pressure_gradient';
print(fig1,'-djpeg',fig_name)



fig2=figure(2);
plot(angle,grad_max)   
xlim([0 90])
xlabel('Angle [degrees]')
ylabel('Pressure gradient [N/mm]')
legend('Max pressure gradient','Location','NorthEastOutside')
title_handle = {'Analytical solution for pressure gradient, Alpha = 0.9, 1e-3 m^2/s in viscosity,';...
    '0.25 in amplitude and frequency of 300 Hz.'};
title(title_handle,'FontWeight','bold')
set(gca, 'ActivePositionProperty', 'OuterPosition');
fig_name = 'max_pressure_gradient';
print(fig2,'-djpeg',fig_name)

