% File to extract data from the forces.dat files that are generated during
% OpenFOAM simulations.
% Copyright Marius grd

clc
clear all

format short

teller = 1;
start_visc = 1;
end_visc = 9;
N_freq = end_visc/start_visc;


for jter=1:N_freq
    
leg(teller,:) = {sprintf('Viscosity of %1.0fe-4 m^2/s',jter)};

teller = teller +1;
    
temp = sprintf('viscosity%1.0fe-4_150Hz/forces/0/forces.dat',jter);
    
fid = fopen(temp,'rt');

formatSpec = '%f(((%f %f %f) (%f %f %f)) ((%f %f %f) (%f %f %f)))';
delimiter_input = ['\t'];
C = textscan(fid,formatSpec,'Delimiter',delimiter_input,'CommentStyle',{'#'});
fclose(fid);

%# put columns in separate variables

% A = 'pressure_x'
% B = 'pressure_y'
% C = 'pressure_z'
% D = 'viscous_x'
% E = 'viscous_y'
% F = 'viscous_z'
% G = 'mom_pressure_x'
% H = 'mom_pressure_y'
% I = 'mom_pressure_z'
% J = 'mom_viscous_x'
% K = 'mom_viscous_y'
% L = 'mom_viscous_z'

[time,A,B,C,D,E,F,G,H,I,J,K,L] = deal(C{:});

fig1 = figure(1);
hold all

plot(time(100:14000),B(100:14000)) % Note that this is the stable area, high forces in the beginning and unstabilities in the end.

end

xlabel('Time [s]')
ylabel('Force per length unit [N/mm]')
legend(leg,'Location','NorthEastOutside')
title_handle = {'Pressure force for alpha=0.9, 150 Hz in frequency,';...
    'and 0.25 in amplitude and viscosities from 1e-4 to 9e-4 m^2/s.'};
title(title_handle,'FontWeight','bold')
set(gca, 'ActivePositionProperty', 'OuterPosition');
fig_name = 'pressure_force_visc_summary';
print(fig1,'-djpeg',fig_name)
