clc
clear all

teller = 1;

% alpha = {sprintf('05'),sprintf('06'),sprintf('07'),sprintf('08'),sprintf('085'),sprintf('09'),sprintf('092'),sprintf('094')};
alpha = {sprintf('05'),sprintf('06'),sprintf('07'),sprintf('08'),sprintf('085'),sprintf('09'),sprintf('092')};
alpha_numb = [0.5 0.6 0.7 0.8 0.85 0.9 0.92];
N_alpha = length(alpha);

% N_visc = 3; % Number of viscosity samples
% start_visc = 3;

visc = {sprintf('1e-3'),sprintf('9e-4'),sprintf('8e-4'),sprintf('7e-4'),sprintf('6e-4'),sprintf('5e-4'),sprintf('4e-4'),sprintf('3e-4'),sprintf('2e-4'),sprintf('1e-4')};
visc_numb = [1e-3 9e-4 8e-4 7e-4 6e-4 5e-4 4e-4 3e-4 2e-4 1e-4];

N_visc = length(visc);

leg = cell(N_alpha,1);
leg(:,:) = {''};

    i_teller = 1;
    v_teller = 101;

for iter=1:N_visc

    for jter=1:N_alpha
        
        leg(jter,:) = {sprintf('Alpha value of %s ',alpha{jter})};

        temp = sprintf('visc%s_alpha%s/forces/0/forces.dat',visc{iter},alpha{jter});
    
        fid = fopen(temp,'rt');

        formatSpec = '%f(((%f %f %f) (%f %f %f)) ((%f %f %f) (%f %f %f)))';
        delimiter_input = ['\t'];
        C = textscan(fid,formatSpec,'Delimiter',delimiter_input,'CommentStyle',{'#'});
        fclose(fid);

        %# put columns in separate variables
        [time,A,B,C,D,E,F,G,H,I,J,K,L] = deal(C{:});

        temp_pressure = B(350:end);
        temp_visc = E(350:end);
        
        stored_pressure(jter,:) = temp_pressure;
        stored_visc(jter,:) = temp_visc;

        force_max_pressure(iter,jter) = max(temp_pressure);
        force_max_visc(iter,jter) = max(temp_visc);

    end
    
    hold all
    figure(i_teller);
        
    plot(stored_pressure')
            
    xlabel('Time [s]')
    ylabel('Force per length unit [N/mm]')
    legend(leg,'Location','NorthEastOutside')
    title_handle = {sprintf('Pressure force for different alpha values, %s m^2/s in viscosity,',visc{iter});...
    '0.25 in amplitude and frequency of 300 Hz.'};
    title(title_handle,'FontWeight','bold')
    set(gca, 'ActivePositionProperty', 'OuterPosition');
    fig_name = sprintf('pressure_force_alpha_viscosity_%s',visc{iter});
    print(figure(i_teller),'-djpeg',fig_name)

    hold off
    
    i_teller = i_teller + 1;
    
    hold all

    figure(v_teller)
    plot(stored_visc')
    xlabel('Time [s]')
    ylabel('Force per length unit [N/mm]')
    legend(leg,'Location','NorthEastOutside')
    title_handle = {sprintf('Viscous force for different alpha values, %s m^2/s in viscosity,',visc{iter});...
    '0.25 in amplitude and frequency of 300 Hz.'};
    title(title_handle,'FontWeight','bold')
    set(gca, 'ActivePositionProperty', 'OuterPosition');
    fig_name = sprintf('viscous_force_alpha_viscosity_%s',visc{iter});
    print(figure(v_teller),'-djpeg',fig_name)
    
    hold off
    
    v_teller = v_teller + 1;

% a = sprintf('pressure_x%3.0Hz',jter*start_freq);
% b = sprintf('pressure_y%3.0Hz',jter*start_freq);
% c = sprintf('pressure_z%3.0Hz',jter*start_freq);
% d = sprintf('viscous_x%3.0Hz',jter*start_freq);
% e = sprintf('viscous_y%3.0Hz',jter*start_freq);
% f = sprintf('viscous_z%3.0Hz',jter*start_freq);
% g = sprintf('mom_pressure_x%3.0Hz',jter*start_freq);
% h = sprintf('mom_pressure_y%3.0Hz',jter*start_freq);
% i = sprintf('mom_pressure_z%3.0Hz',jter*start_freq);
% j = sprintf('mom_viscous_x%3.0Hz',jter*start_freq);
% k = sprintf('mom_viscous_y%3.0Hz',jter*start_freq);
% l = sprintf('mom_viscous_z%3.0Hz',jter*start_freq);

    rel_pressure_force_max(iter,:) = force_max_pressure(iter,:)./force_max_pressure(iter,1);
    rel_viscous_force_max(iter,:) = force_max_visc(iter,:)./force_max_visc(iter,1);
    leg2(iter,:) = {sprintf('Viscosity of %s',visc{iter})};

end

%% Processing of the force_max variable

hold all
figure(i_teller+1);
plot(alpha_numb,rel_pressure_force_max')

xlabel('Alpha value [-]')
ylabel('Relative maximum pressure force [-]')
legend(leg2,'Location','NorthEastOutside')
title_handle = {'Relative maximum pressure force for different viscosity and alpha values,';...
    '0.25 in amplitude and frequency of 300 Hz.'};
title(title_handle,'FontWeight','bold')
set(gca, 'ActivePositionProperty', 'OuterPosition');
fig_name = 'relative_max_pressure_force';
print(figure(i_teller+1),'-djpeg',fig_name)

hold off

hold all
figure(teller+2);
plot(alpha_numb,rel_viscous_force_max')

xlabel('Alpha value [-]')
ylabel('Relative maximum viscous force [-]')
legend(leg2,'Location','NorthEastOutside')
title_handle = {'Relative maximum viscous force for different viscosity and alpha values,';...
    '0.25 in amplitude and frequency of 300 Hz.'};
title(title_handle,'FontWeight','bold')
set(gca, 'ActivePositionProperty', 'OuterPosition');
fig_name = 'relative_max_viscous_force';
print(figure(i_teller+2),'-djpeg',fig_name)

hold off

%%